@@ -1,4 +1,5 @@
 from ckan.tests import *
+import ckan.model as model
 
 class TestAccountController(TestController2):
 
@@ -12,7 +13,7 @@ class TestAccountController(TestController2):
     def test_account_login(self):
         offset = url_for(controller='account', action='login')
         res = self.app.get(offset, status=401)
-        assert 'Please Sign In' in res
+        assert 'Please login now' in res
         # cannot use with AuthKit 0.4.0 (see below)
         # res = self._login_form(res)
         # neither does this plus it is slow as it is external
@@ -91,3 +92,23 @@ class TestAccountController(TestController2):
      # a) a username at top of page
      # b) logout link
 
+    def test_apikey(self):
+        from sqlobject import SQLObjectNotFound
+        # not_logged_in
+        try:
+            key = model.ApiKey.byName('okfntest')
+            model.ApiKey.delete(key.id)
+        except SQLObjectNotFound:
+            pass
+
+        offset = url_for(controller='account', action='apikey')
+        res = self.app.get(offset, status=[401]) 
+
+        res = self.app.get(offset, extra_environ=dict(REMOTE_USER='okfntest'))
+        key = model.ApiKey.byName('okfntest')
+        assert 'Your API key is: %s' % key.key in res, res
+
+        # run again to check case where ApiKey already exists
+        res = self.app.get(offset, extra_environ=dict(REMOTE_USER='okfntest'))
+        key = model.ApiKey.byName('okfntest')
+        assert 'Your API key is: %s' % key.key in res, res
