@@ -1,5 +1,4 @@
 from ckan.tests import *
-# Todo: Move this file to tests/controller/test_tag.py?
 
 class TestTagController(TestController2):
 
@@ -20,83 +19,72 @@ class TestTagController(TestController2):
         res = res.click(pkgname)
         assert 'Packages - %s' % pkgname in res
 
-    def test_list(self):
-        tagname = 'tolstoy'
+    def test_list_short(self):
         offset = url_for(controller='tag', action='list')
         res = self.app.get(offset)
-        assert 'Tags - List' in res
-        assert tagname in res
-        print str(res)
-        assert '(2 packages)' in res
-        res = res.click(tagname)
-        assert 'Tags - %s' % tagname in res
-    
-    def test_page_short(self):
-        offset = url_for(controller='tag', action='page')
-        res = self.app.get(offset)
         print str(res)
         assert 'Tags - List' in res
         tagname = 'tolstoy'
         assert tagname in res
-        assert '(2 packages)' in res
+        #assert '(2 packages)' in res
         res = res.click(tagname)
         assert 'Tag: %s' % tagname in res
-        offset = url_for(controller='tag', action='page', id=0)
+        offset = url_for(controller='tag', action='list', id=0)
         res = self.app.get(offset)
         print str(res)
         assert 'Tags - List' in res
         assert tagname in res
-        assert '(2 packages)' in res
+        #assert '(2 packages)' in res
         assert 'There are 2 tags.' in res
-        offset = url_for(controller='tag', action='page', id=50)
+        offset = url_for(controller='tag', action='list', id=50)
         res = self.app.get(offset)
         print str(res)
         assert 'Tags - List' in res
         assert tagname in res
         assert 'There are 2 tags.' in res
         # Avoid interactions.
-        offset = url_for(controller='tag', action='page', id=0)
+        offset = url_for(controller='tag', action='list', id=0)
     
-    def test_page_long(self):
+    def test_list_long(self):
         self.create_100_tags()
         try:
-            # Page 0.
+            # Page 1.
             print
-            offset = url_for(controller='tag', action='page', id=0)
+            offset = url_for(controller='tag', action='list', id=1)
             print offset
             res = self.app.get(offset)
             print str(res)
             assert 'Tags - List' in res
-            assert 'tolstoy' in res
-            assert 'pagetesttag31' in res
-            assert not 'pagetesttag81' in res
-            assert not 'pagetesttag99' in res
+            # tolstoy not in because now a 100 tags starting 'test'
+            assert 'tolstoy' not in res
+            assert 'testtag31' in res
+            assert not 'testtag81' in res
+            assert not 'testtag99' in res
             assert 'Next' in res
             assert not 'Previous' in res
             assert 'Displaying tags 1 - 50 of 102' in res
-            # Page 1.
-            offset = url_for(controller='tag', action='page', id=50)
+            # Page 2.
+            offset = url_for(controller='tag', action='list', id=2)
             print offset
             print "Path offset: %s" % offset
             res = self.app.get(offset)
             print str(res)
             assert 'Tags - List' in res
             assert not 'tolstoy' in res
-            assert not 'pagetesttag31' in res
-            assert 'pagetesttag81' in res
+            assert not 'testtag31' in res
+            assert 'testtag81' in res
             assert 'Next' in res
             assert 'Previous' in res
             assert 'Displaying tags 51 - 100 of 102' in res
-            # Page 2.
-            offset = url_for(controller='tag', action='page', id=100)
+            # Page 3.
+            offset = url_for(controller='tag', action='list', id=3)
             res = self.app.get(offset)
             print str(res)
             assert 'Tags - List' in res
-            assert not 'tolstoy' in res
-            assert not 'pagetesttag31' in res
-            assert not 'pagetesttag81' in res
-            assert 'pagetesttag98' in res
-            assert 'pagetesttag99' in res
+            assert not 'testtag31' in res
+            assert not 'testtag81' in res
+            assert 'tolstoy' in res
+            assert 'testtag99' in res
             assert not 'Next' in res
             assert 'Previous' in res
             assert 'Displaying tags 101 - 102 of 102' in res
@@ -117,3 +105,16 @@ class TestTagController(TestController2):
         assert 'russian' in res
         assert 'tolstoy' in res
 
+    def test_autocomplete(self):
+        offset = url_for(controller='tag', action='autocomplete')
+        res = self.app.get(offset)
+        assert '[]' in res
+        offset = url_for(controller='tag', action='autocomplete', incomplete='russian')
+        res = self.app.get(offset)
+        assert 'russian' in res
+        assert 'tolstoy' not in res
+        offset = url_for(controller='tag', action='autocomplete', incomplete='tolstoy')
+        res = self.app.get(offset)
+        assert 'russian' not in res
+        assert 'tolstoy' in res
+
